summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNick White <git@njw.me.uk>2010-11-13 18:54:00 +0000
committerNick White <git@njw.me.uk>2010-11-13 18:54:00 +0000
commit3d293ecb997547ce48ab5ee3c6a83effddbbb0ae (patch)
tree87553f863bbd48a8268ccbebd71a3a7783c720e0
parent6184d6bdac39e3a1f2e72ce180db40cb896724cf (diff)
Rename to simplyread to avoid name clash
-rw-r--r--BUGS4
-rw-r--r--COPYING2
-rw-r--r--INSTALL24
-rw-r--r--Makefile20
-rw-r--r--README12
-rw-r--r--TODO2
-rw-r--r--chromium/background.html4
-rw-r--r--chromium/manifest.json4
-rw-r--r--doap.ttl14
-rw-r--r--gecko/chrome.manifest4
-rw-r--r--gecko/chrome/content/readable.xul10
-rw-r--r--gecko/chrome/content/simplyread.xul10
-rw-r--r--gecko/install.rdf8
-rwxr-xr-xsimplyread.js (renamed from readable.js)18
-rw-r--r--webheader.html2
15 files changed, 69 insertions, 69 deletions
diff --git a/BUGS b/BUGS
index 512d7a8..85023d3 100644
--- a/BUGS
+++ b/BUGS
@@ -7,5 +7,5 @@ are disabled in firefox. Subsequent runs are fine. Presumably it's a
bug in firefox; should report it to them.
When run as a bookmarklet in firefox, the first run it hasn't registered
-readable() by the time it is called. Subsequent runs work fine. This
-occurs whether readable is in a separate javascript: clause or not.
+simplyread() by the time it is called. Subsequent runs work fine. This
+occurs whether simplyread is in a separate javascript: clause or not.
diff --git a/COPYING b/COPYING
index a1b8ecd..cf4e447 100644
--- a/COPYING
+++ b/COPYING
@@ -1,4 +1,4 @@
-Readable is Copyright 2010 Nick White. It is licensed under the
+SimplyRead is Copyright 2010 Nick White. It is licensed under the
GNU Affero General Public License version 3, or any later version.
GNU AFFERO GENERAL PUBLIC LICENSE
diff --git a/INSTALL b/INSTALL
index 65a948e..59fe2cb 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,10 +1,10 @@
-Readable is written in ECMAScript, and how to launch it varies a
+SimplyRead is written in ECMAScript, and how to launch it varies a
little depending on browser.
# Firefox
-Readable is now packaged as an extension for firefox (and other
-browsers of its kin.) You can either get it from the readable web
+SimplyRead is now packaged as an extension for firefox (and other
+browsers of its kin.) You can either get it from the SimplyRead web
page, or build it by running:
make xpi
@@ -12,16 +12,16 @@ page, or build it by running:
# Chromium
-Readable also exists as an extension for chromium (and derived
+SimplyRead also exists as an extension for chromium (and derived
browsers.) It isn't currently available on the "extensions gallery,"
but if someone wants to post it there, please go ahead. For now
-you can get it from the readable web page, or by running:
+you can get it from the SimplyRead web page, or by running:
make crx
# Surf
-To use readable from surf, and trigger it from ctrl-alt-r, add the
+To use SimplyRead from surf, and trigger it from ctrl-alt-r, add the
following to script.js
(function() {
@@ -30,26 +30,26 @@ following to script.js
function keybind(e) {
if (e.keyIdentifier == "U+0052" && e.ctrlKey && e.altKey) // ctrl-alt-r
- readable();
+ simplyread();
}
-/* copy readable.js here */
+/* copy simplyread.js here */
# Uzbl
To use this from uzbl, add the following line to the config file:
-@cbind r = script file:///path/to/readable.js
+@cbind r = script file:///path/to/simplyread.js
-You'll also have to add the statement 'readable();' to the bottom of
-readable.js.
+You'll also have to add the statement 'simplyread();' to the bottom of
+simplyread.js.
# Other browsers; 'bookmarklet'
To use this as a 'bookmarklet', create a new bookmark with an address of:
-javascript:(function(){document.body.appendChild(document.createElement('script')).src='file:///path/to/readable.js';})();javascript:(function(){readable();})();
+javascript:(function(){document.body.appendChild(document.createElement('script')).src='file:///path/to/simplyread.js';})();javascript:(function(){simplyread();})();
Note that due to browsers being afraid of mixing local and remote files
this may not work for http:// addresses. If this is the case, you can
diff --git a/Makefile b/Makefile
index 026015b..1038850 100644
--- a/Makefile
+++ b/Makefile
@@ -1,15 +1,15 @@
-NAME = readable
+NAME = simplyread
VERSION = 0.2
index.html: doap.ttl README webheader.html
@echo making webpage
@cat < webheader.html > $@
@smu < README >> $@
- @echo '<h3><a href="$(NAME)-$(VERSION).tar.bz2">Download Readable $(VERSION)</a><br />' >> $@
+ @echo '<h3><a href="$(NAME)-$(VERSION).tar.bz2">Download SimplyRead $(VERSION)</a><br />' >> $@
@echo '<a href="$(NAME)-$(VERSION).tar.bz2.sig">GPG signature</a></h3>' >> $@
- @echo '<h3><a href="$(NAME)-$(VERSION).xpi">Readable $(VERSION) for Firefox</a><br />' >> $@
+ @echo '<h3><a href="$(NAME)-$(VERSION).xpi">SimplyRead $(VERSION) for Firefox</a><br />' >> $@
@echo '<a href="$(NAME)-$(VERSION).xpi.sig">GPG signature</a></h3>' >> $@
- @echo '<h3><a href="$(NAME)-$(VERSION).crx">Readable $(VERSION) for Chromium</a><br />' >> $@
+ @echo '<h3><a href="$(NAME)-$(VERSION).crx">SimplyRead $(VERSION) for Chromium</a><br />' >> $@
@echo '<a href="$(NAME)-$(VERSION).xpi.crx">GPG signature</a></h3>' >> $@
@echo '<hr />' >> $@
@sh summary.sh doap.ttl | smu >> $@
@@ -17,7 +17,7 @@ index.html: doap.ttl README webheader.html
dist:
@mkdir -p $(NAME)-$(VERSION)
- @cp readable.js COPYING INSTALL README $(NAME)-$(VERSION)
+ @cp simplyread.js COPYING INSTALL README $(NAME)-$(VERSION)
@tar -c $(NAME)-$(VERSION) | bzip2 -c > $(NAME)-$(VERSION).tar.bz2
@gpg -b < $(NAME)-$(VERSION).tar.bz2 > $(NAME)-$(VERSION).tar.bz2.sig
@rm -rf $(NAME)-$(VERSION)
@@ -25,12 +25,12 @@ dist:
@ln -sf $(NAME)-$(VERSION).tar.bz2.sig latest.tar.bz2.sig
@echo $(NAME)-$(VERSION).tar.bz2 $(NAME)-$(VERSION).tar.bz2.sig
-xpi: readable.js gecko/install.rdf gecko/chrome.manifest gecko/chrome/content/readable.xul gecko/chrome/content/icon.svg
+xpi: simplyread.js gecko/install.rdf gecko/chrome.manifest gecko/chrome/content/simplyread.xul gecko/chrome/content/icon.svg
@rm -rf $(NAME)-$(VERSION).xpi gecko-build
@mkdir -p gecko-build/chrome/content
@cp COPYING gecko/chrome.manifest gecko-build/
- @cp gecko/chrome/content/readable.xul gecko-build/chrome/content/
- @cp readable.js gecko-build/chrome/content/readable.js
+ @cp gecko/chrome/content/simplyread.xul gecko-build/chrome/content/
+ @cp simplyread.js gecko-build/chrome/content/simplyread.js
@rsvg gecko/chrome/content/icon.svg gecko-build/chrome/content/icon.png
@sed "s/VERSION/$(VERSION)/g" < gecko/install.rdf > gecko-build/install.rdf
@cd gecko-build; zip -r ../$(NAME)-$(VERSION).xpi . 1>/dev/null
@@ -38,10 +38,10 @@ xpi: readable.js gecko/install.rdf gecko/chrome.manifest gecko/chrome/content/re
@rm -rf gecko-build
@echo $(NAME)-$(VERSION).xpi $(NAME)-$(VERSION).xpi.sig
-crx: readable.js chromium/icon.svg chromium/manifest.json chromium/background.html
+crx: simplyread.js chromium/icon.svg chromium/manifest.json chromium/background.html
@rm -rf chromium-build
@mkdir chromium-build
- @cp COPYING readable.js chromium/background.html chromium-build/
+ @cp COPYING simplyread.js chromium/background.html chromium-build/
@rsvg chromium/icon.svg chromium-build/icon.png
@sed "s/VERSION/$(VERSION)/g" < chromium/manifest.json > chromium-build/manifest.json
@chromium-browser --pack-extension=chromium-build
diff --git a/README b/README
index 6c8357e..e8240c8 100644
--- a/README
+++ b/README
@@ -1,13 +1,13 @@
-Readable
-========
+SimplyRead
+==========
-Readable is a simple program to remove unwanted distractions from
-webpages, in order to better enjoy reading on the web. It removes
-everything but the article from a webpage, displaying it
+SimplyRead is a simple program to remove unwanted distractions
+from webpages, in order to better enjoy reading on the web. It
+removes everything but the article from a webpage, displaying it
simply and attractively.
Running the program multiple times switches between showing the
-original page and the 'readable' version.
+original page and the simple version.
This project is technically inspired by Arc90's Readability,
but aims to be much simpler, faster, and more usable. More
diff --git a/TODO b/TODO
index d5a07eb..77c2145 100644
--- a/TODO
+++ b/TODO
@@ -1,10 +1,10 @@
-rename as there's already a similar program called readable. simply read seems good
chromium extension http://code.google.com/chrome/extensions/index.html
packaging
http://code.google.com/chrome/extensions/packaging.html
http://code.google.com/chrome/extensions/hosting.html
http://code.google.com/chrome/extensions/crx.html
use a simple script to create crx rather than chromium-browser
+ is the script src=simplyread in background.html necessary?
handle signing extension properly
epiphany extension http://projects.gnome.org/epiphany/extensions
make tests, which process sample html files and check the output
diff --git a/chromium/background.html b/chromium/background.html
index 669ff78..229610d 100644
--- a/chromium/background.html
+++ b/chromium/background.html
@@ -1,5 +1,5 @@
-<html><head><script src="readable.js"></script><script>
+<html><head><script src="simplyread.js"></script><script>
chrome.browserAction.onClicked.addListener(function(tab) {
- chrome.tabs.executeScript(null, {code:"readable();"});
+ chrome.tabs.executeScript(null, {code:"simplyread();"});
});
</script></head></html>
diff --git a/chromium/manifest.json b/chromium/manifest.json
index 875c633..56c51fa 100644
--- a/chromium/manifest.json
+++ b/chromium/manifest.json
@@ -1,8 +1,8 @@
{
- "name": "Readable",
+ "name": "SimplyRead",
"version": "VERSION",
"background_page": "background.html",
"permissions": [ "tabs", "*://*/*" ],
- "content_scripts": [{"matches": ["*://*/*"], "js": ["readable.js"]}],
+ "content_scripts": [{"matches": ["*://*/*"], "js": ["simplyread.js"]}],
"browser_action": { "default_icon": "icon.png" }
}
diff --git a/doap.ttl b/doap.ttl
index e85fe4a..4ebfb9d 100644
--- a/doap.ttl
+++ b/doap.ttl
@@ -1,12 +1,12 @@
@prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>.
@prefix doap: <http://usefulinc.com/ns/doap#>.
@prefix foaf: <http://xmlns.com/foaf/0.1/>.
-@prefix : <http://njw.me.uk/software/readable/#>.
+@prefix : <http://njw.me.uk/software/simplyread/#>.
:p a doap:Project;
- doap:name "Readable";
+ doap:name "SimplyRead";
doap:shortdesc "Makes webpages more readable";
- doap:homepage <http://njw.me.uk/software/readable/>;
+ doap:homepage <http://njw.me.uk/software/simplyread/>;
doap:repository :repo;
doap:programming-language "ECMAScript";
doap:license <http://www.gnu.org/licenses/agpl.html>;
@@ -18,15 +18,15 @@
foaf:homepage <http://njw.me.uk>.
:repo a doap:GitRepository;
- doap:location <http://git.njw.me.uk/readable.git>.
+ doap:location <http://git.njw.me.uk/simplyread.git>.
:v0.1 a doap:Version;
doap:revision "0.1";
doap:created "2010-10-23";
- doap:file-release <http://njw.me.uk/software/readable/readable-0.1.tar.bz2>.
+ doap:file-release <http://njw.me.uk/software/simplyread/simplyread-0.1.tar.bz2>.
:v0.2 a doap:Version;
doap:revision "0.2";
doap:created "2010-11-04";
- doap:file-release <http://njw.me.uk/software/readable/readable-0.2.tar.bz2>,
- <http://njw.me.uk/software/readable/readable-0.2.xpi>.
+ doap:file-release <http://njw.me.uk/software/simplyread/simplyread-0.2.tar.bz2>,
+ <http://njw.me.uk/software/simplyread/simplyread-0.2.xpi>.
diff --git a/gecko/chrome.manifest b/gecko/chrome.manifest
index fa8891b..837e8e8 100644
--- a/gecko/chrome.manifest
+++ b/gecko/chrome.manifest
@@ -1,2 +1,2 @@
-content readable chrome/content/
-overlay chrome://browser/content/browser.xul chrome://readable/content/readable.xul
+content simplyread chrome/content/
+overlay chrome://browser/content/browser.xul chrome://simplyread/content/simplyread.xul
diff --git a/gecko/chrome/content/readable.xul b/gecko/chrome/content/readable.xul
deleted file mode 100644
index 75ab8fd..0000000
--- a/gecko/chrome/content/readable.xul
+++ /dev/null
@@ -1,10 +0,0 @@
-<?xml version="1.0"?>
-<overlay id="readable" xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul">
- <script src="chrome://readable/content/readable.js" />
- <keyset>
- <key id="readable" modifiers="accel alt" key="r" oncommand="readable()" />
- </keyset>
- <statusbar id="status-bar">
- <image id="readable-icon" src="chrome://readable/content/icon.png" onclick="readable()" />
- </statusbar>
-</overlay>
diff --git a/gecko/chrome/content/simplyread.xul b/gecko/chrome/content/simplyread.xul
new file mode 100644
index 0000000..f216c41
--- /dev/null
+++ b/gecko/chrome/content/simplyread.xul
@@ -0,0 +1,10 @@
+<?xml version="1.0"?>
+<overlay id="simplyread" xmlns="http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul">
+ <script src="chrome://simplyread/content/simplyread.js" />
+ <keyset>
+ <key id="simplyread" modifiers="accel alt" key="r" oncommand="simplyread()" />
+ </keyset>
+ <statusbar id="status-bar">
+ <image id="simplyread-icon" src="chrome://simplyread/content/icon.png" onclick="simplyread()" />
+ </statusbar>
+</overlay>
diff --git a/gecko/install.rdf b/gecko/install.rdf
index b00b1a7..81ea31c 100644
--- a/gecko/install.rdf
+++ b/gecko/install.rdf
@@ -6,7 +6,7 @@
xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
<Description about="urn:mozilla:install-manifest">
- <em:id>readable@njw.me.uk</em:id>
+ <em:id>simplyread@njw.me.uk</em:id>
<em:version>VERSION</em:version>
<em:type>2</em:type>
@@ -18,10 +18,10 @@
</Description>
</em:targetApplication>
- <em:name>Readable</em:name>
- <em:description>Makes webpages more readable. Press Ctrl-Alt-r or click the 'r' icon in the status bar to toggle readable.</em:description>
+ <em:name>SimplyRead</em:name>
+ <em:description>Makes webpages more readable. Press Ctrl-Alt-r or click the 'r' icon in the status bar to toggle SimplyRead.</em:description>
<em:creator>Nick White</em:creator>
- <em:homepageURL>http://njw.me.uk/software/readable/</em:homepageURL>
+ <em:homepageURL>http://njw.me.uk/software/simplyread/</em:homepageURL>
<doap:license rdf:resource="http://www.gnu.org/licenses/agpl.html"/>
</Description>
</RDF>
diff --git a/webheader.html b/webheader.html
index bd879fb..ff3a7da 100644
--- a/webheader.html
+++ b/webheader.html
@@ -11,5 +11,5 @@ h3 a:hover { text-decoration: underline }
img { display: block; margin: auto; }
</style>
<link rel="alternate" type="text/turtle" title="rdf" href="doap.ttl" />
-<title>Readable - Makes webpages more readable</title>
+<title>SimplyRead - Makes webpages more readable</title>
</head><body>
diff --git a/readable.js b/simplyread.js
index 8a897ca..170c4d8 100755
--- a/readable.js
+++ b/simplyread.js
@@ -1,12 +1,12 @@
/*
* Readable - makes webpages more readable
*
* See COPYING file for copyright, license and warranty details.
*/
-if(window.content && window.content.document.readable_original === undefined) window.content.document.readable_original = false;
+if(window.content && window.content.document.simplyread_original === undefined) window.content.document.simplyread_original = false;
-function readable()
+function simplyread()
{
/* count the number of <p> tags that are direct children of parenttag */
function count_p(parenttag)
@@ -26,17 +26,17 @@ function readable()
else
doc = document;
- /* if readable_original is set, then the readable version is currently active,
- * so switch to the readable_original html */
- if (doc.readable_original) {
- doc.body.innerHTML = doc.readable_original;
+ /* if simplyread_original is set, then the simplyread version is currently active,
+ * so switch to the simplyread_original html */
+ if (doc.simplyread_original) {
+ doc.body.innerHTML = doc.simplyread_original;
for (var i = 0; i < doc.styleSheets.length; i++)
doc.styleSheets[i].disabled = false;
- doc.readable_original = false
+ doc.simplyread_original = false
return 0;
}
- doc.readable_original = doc.body.innerHTML;
+ doc.simplyread_original = doc.body.innerHTML;
var biggest_num = 0;
var biggest_tag;
@@ -1,12 +1,12 @@
/*
- * Readable - makes webpages more readable
+ * SimplyRead - makes webpages more simplyread
*
* See COPYING file for copyright, license and warranty details.